Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(597)

Unified Diff: runtime/bin/secure_socket.h

Issue 11419138: Rename TlsSocket to SecureSocket, and all other Tls... items to Secure.... (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Rename C++ class from Filter to SSLFilter. Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/io_sources.gypi ('k') | runtime/bin/secure_socket.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/secure_socket.h
diff --git a/runtime/bin/tls_socket.h b/runtime/bin/secure_socket.h
similarity index 88%
rename from runtime/bin/tls_socket.h
rename to runtime/bin/secure_socket.h
index 407b998ac6e5203705dba963ae1bd2338a1042cf..22ef7dcc817bd98df719cc3f9b68b1054508ab95 100644
--- a/runtime/bin/tls_socket.h
+++ b/runtime/bin/secure_socket.h
@@ -2,8 +2,8 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-#ifndef BIN_TLS_SOCKET_H_
-#define BIN_TLS_SOCKET_H_
+#ifndef BIN_SECURE_SOCKET_H_
+#define BIN_SECURE_SOCKET_H_
#include <stdlib.h>
#include <string.h>
@@ -44,15 +44,15 @@ static void ThrowPRException(const char* message) {
}
/*
* TlsFilter encapsulates the NSS SSL(TLS) code in a filter, that communicates
* with the containing _TlsFilterImpl Dart object through four shared
* ExternalByteArray buffers, for reading and writing plaintext, and
* reading and writing encrypted text. The filter handles handshaking
* and certificate verification.
*/
-class TlsFilter {
+class SSLFilter {
public:
- // These enums must agree with those in sdk/lib/io/tls_socket.dart.
+ // These enums must agree with those in sdk/lib/io/secure_socket.dart.
enum BufferIndex {
kReadPlaintext,
kWritePlaintext,
@@ -61,7 +61,7 @@ class TlsFilter {
kNumBuffers
};
- TlsFilter()
+ SSLFilter()
: string_start_(NULL),
string_length_(NULL),
handshake_complete_(NULL),
@@ -100,7 +100,7 @@ class TlsFilter {
void InitializeBuffers(Dart_Handle dart_this);
void InitializePlatformData();
- DISALLOW_COPY_AND_ASSIGN(TlsFilter);
+ DISALLOW_COPY_AND_ASSIGN(SSLFilter);
};
-#endif // BIN_TLS_SOCKET_H_
+#endif // BIN_SECURE_SOCKET_H_
« no previous file with comments | « runtime/bin/io_sources.gypi ('k') | runtime/bin/secure_socket.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -44,15 +44,15 @@ static void ThrowPRException(const char* message) {
}
/*
- * TlsFilter encapsulates the NSS SSL(TLS) code in a filter, that communicates
- * with the containing _TlsFilterImpl Dart object through four shared
+ * SSLFilter encapsulates the NSS SSL(TLS) code in a filter, that communicates
+ * with the containing _SecureFilterImpl Dart object through four shared
* ExternalByteArray buffers, for reading and writing plaintext, and
* reading and writing encrypted text. The filter handles handshaking
This is Rietveld 408576698